function [] = calc_rev(AD0,HP1,SNAPi,GEN)

% calculate metric to quantify reamplification
% compare original heterochromatin/euchromatin classification with final het/eu classification 
% excludes nucleosomes in centromere from calculation of window averages and correlation metric

load(['data/gen',num2str(GEN),'/v',num2str(HP1),'/ad',num2str(AD0),'.mat'])

delta = 50; % window size for determining condensation state 
% (number of nucleosomes on either side of nucleosome in question)

Lfirst = 1; % first nucleosome in left segment
Llast = 176131; % last nucleosome to left of centromere
Rfirst = 231630; % first nucleosome to right of centromere
Rlast = NN; % last nucleosome in right segment
section = [Lfirst:Llast,Rfirst:Rlast];

FMi_nuc = zeros(NN,1); % initial fraction methylated in window
FMi_tail = zeros(NN,1);
FMf_nuc = zeros(NN,1); % final fraction methylated in window
FMf_tail = zeros(NN,1);

str = char('input/gen1/r%dv%d/methoriginal.mat');
filename = sprintf(str,SNAPi,HP1);
load(filename)

MS = dlmread(['data/gen',num2str(GEN),'/v',num2str(HP1),'/methfinal_ad',num2str(AD0),'.txt']);

FM_nuc = sum(MS~=0)/NN; % overall fraction of nucleosomes methylated
FM_tail = sum(MS)/(2*NN); % overall fraction of tails methylated
FM_nucnocentr = sum(MS(section)~=0)/length(section); % overall fraction of nucleosomes methylated, excluding centromere
FM_tailnocentr = sum(MS(section))/(2*length(section)); % overall fraction of tails methylated, excluding centromere

for I = 1:NN

    if I<=Llast
        start = max(1,I-delta);
        stop = min(I+delta,Llast);
    elseif I>=Rfirst
        start = max(Rfirst,I-delta);
        stop = min(I+delta,NN);
    else
        start = I;
        stop = I;
    end
      
    FNM_nuc = sum(MS(start:stop)~=0)/(stop-start+1); % fraction of nucleosomes methylated in window
    FNM_tail = sum(MS(start:stop))/(2*(stop-start+1)); % fraction of tails methylated in window

    FMf_nuc(I) = FNM_nuc;
    FMf_tail(I) = FNM_tail;
    
end


for I = 1:NN
    
    if I<=Llast
        start = max(1,I-delta);
        stop = min(I+delta,Llast);
    elseif I>=Rfirst
        start = max(Rfirst,I-delta);
        stop = min(I+delta,NN);
    else
        start = I;
        stop = I;
    end
    
    FNM_nuc = sum(methoriginal(start:stop)~=0)/(stop-start+1); % fraction of nucleosomes methylated in window
    FNM_tail = sum(methoriginal(start:stop))/(2*(stop-start+1)); % fraction of tails methylated in window
 
    FMi_nuc(I) = FNM_nuc;
    FMi_tail(I) = FNM_tail;
    
end


FMMCnum = sum((FMi_nuc(section)-mean(FMi_nuc(section))).*(FMf_nuc(section)-mean(FMf_nuc(section))));
FMMCdenom = sqrt(sum((FMi_nuc(section)-mean(FMi_nuc(section))).^2)*sum((FMf_nuc(section)-mean(FMf_nuc(section))).^2));
FMMC = FMMCnum/FMMCdenom;

       
save(['analysis/gen',num2str(GEN),'/data_v',num2str(HP1),'ad',num2str(AD0),'.mat'],'FMMC','FMi_nuc','FMi_tail','FMf_nuc','FMf_tail','FM_nuc','FM_tail','FM_nucnocentr','FM_tailnocentr','delta','-v7.3');


end

