function [] = plot_dynamics_pernuc(HP1,GEN,AD0,delta,SNAPi)
% uses sliding windows of 101 nucleosomes

load(['data/gen',num2str(GEN),'/v',num2str(HP1),'/ad',num2str(AD0),'.mat'])

load(['input/gen1/r',num2str(SNAPi),'v',num2str(HP1),'/methoriginal.mat']);
F = methoriginal; % initial methylation sequence

load(['analysis/gen',num2str(GEN),'/data_v',num2str(HP1),'ad',num2str(AD0),'.mat'])

TI = 0;
DT = 0.001;
TF = 3;

Lfirst = 1; % first nucleosome in left segment
Llast = 176131; % last nucleosome to left of centromere
Rfirst = 231630; % first nucleosome to right of centromere
Rlast = NN; % last nucleosome in right segment
section = [Lfirst:Llast,Rfirst:Rlast];

Ptail_init = F/2;
C = Ptail_init-((AD0*NHNavg)./(AD0*NHNavg+ones(size(NHNavg))));

Ptail = zeros(NN,((TF-TI)/DT)+2);
Pnuc = zeros(NN,((TF-TI)/DT)+2);

I = 1;
for T = [0,TI:DT:TF]
    Ptail(:,I) = (C.*exp(-T*ones(size(NHNavg))-AD0*NHNavg*T))+((AD0*NHNavg)./(AD0*NHNavg+ones(size(NHNavg))));
    Pnuc(:,I) = ones(NN,1) - (ones(NN,1) - Ptail(:,I)).^2;
    I = I + 1;
end

fprintf('probabilities have been calculated \n')
save(['data/gen',num2str(GEN),'/v',num2str(HP1),'/dynamics_metrics_ad',num2str(AD0),'.mat'],'Ptail','Pnuc','Ptail_init','C','TI','DT','TF','-v7.3');

T_inf = 1e6;
Ptail_inf = (C.*exp(-T_inf*ones(size(NHNavg))-AD0*NHNavg*T_inf))+((AD0*NHNavg)./(AD0*NHNavg+ones(size(NHNavg))));
Pnuc_inf = ones(NN,1) - (ones(NN,1) - Ptail_inf).^2;

FMreg = zeros(NN,((TF-TI)/DT)+2);
gmetric = zeros(NN,((TF-TI)/DT)+2);
FMreg_inf = zeros(NN,1);
FMreg_avg = zeros(3,((TF-TI)/DT)+2);
gmetric_avg = zeros(3,((TF-TI)/DT)+2);
FMreg_inf_avg = zeros(3,1); 
count = zeros(3,1);


for I = 1:NN

    if I<=Llast
        startnuc = max(1,I-delta);
        stopnuc = min(I+delta,Llast);
    elseif I>=Rfirst
        startnuc = max(Rfirst,I-delta);
        stopnuc = min(I+delta,NN);
    else
        startnuc = I;
        stopnuc = I;
    end
      
    FMreg(I,:) = sum(Pnuc(startnuc:stopnuc,:),1)/(stopnuc-startnuc+1);  
    FMreg_inf(I) = sum(Pnuc_inf(startnuc:stopnuc))/(stopnuc-startnuc+1);
    
end

fprintf('fraction methylated has been calculated \n')
save(['data/gen',num2str(GEN),'/v',num2str(HP1),'/dynamics_metrics_ad',num2str(AD0),'.mat'],'Ptail','Pnuc','Ptail_init','C','TI','DT','TF','FMreg','-v7.3');

q1 = find(FMi_nuc < 0.377);
q2 = find(FMi_nuc >= 0.377 & FMi_nuc < 0.515);
q3 = find(FMi_nuc >= 0.515);

for I = 1:NN
    gmetric(I,:) = (FMreg(I,:)-FMreg(I,1))/(FMreg_inf(I)-FMreg(I,1));
   
    if ismember(I,q1)==1
        FMreg_avg(1,:) = FMreg_avg(1,:) + FMreg(I,:);
        gmetric_avg(1,:) = gmetric_avg(1,:) + gmetric(I,:);
        FMreg_inf_avg(1) = FMreg_inf_avg(1) + FMreg_inf(I);
        count(1) = count(1) + 1;
    elseif ismember(I,q2)==1
        FMreg_avg(2,:) = FMreg_avg(2,:) + FMreg(I,:);
        gmetric_avg(2,:) = gmetric_avg(2,:) + gmetric(I,:);
        FMreg_inf_avg(2) = FMreg_inf_avg(2) + FMreg_inf(I);
        count(2) = count(2) + 1;
    elseif ismember(I,q3)==1
        FMreg_avg(3,:) = FMreg_avg(3,:) + FMreg(I,:);
        gmetric_avg(3,:) = gmetric_avg(3,:) + gmetric(I,:);
        FMreg_inf_avg(3) = FMreg_inf_avg(3) + FMreg_inf(I);
        count(3) = count(3) + 1;
    end   
end

for I = 1:1:3
    FMreg_avg(I,:) = FMreg_avg(I,:)/count(I);
    gmetric_avg(I,:) = gmetric_avg(I,:)/count(I);
    FMreg_inf_avg(I) = FMreg_inf_avg(I)/count(I);
end

fprintf('gmetric, average fraction methylated, and average g metric have been calculated \n')
save(['data/gen',num2str(GEN),'/v',num2str(HP1),'/dynamics_metrics_ad',num2str(AD0),'.mat'],'Ptail','Pnuc','Ptail_init','C','TI','DT','TF','FMreg','gmetric','FMreg_avg','gmetric_avg','q1','q2','q3','-v7.3');

color = [0,1,1; 0.9290, 0.6940, 0.1250; 1/2,0,1/2];
yasmp = ones(size([0,TI:DT:TF]));

figure()
plot([0,TI:DT:TF],yasmp,'Color','k','LineStyle','--','Linewidth',2)
hold on

for I = 3:-1:1
    plot([0,TI:DT:TF],FMreg_avg(I,:),'Color',color(I,:),'Linewidth',2)
    hold on 
end

xlabel('Time','Fontsize',18)
ylabel('Fraction methylated','Fontsize',18)
set(gca,'Fontsize',14)
str = char('Gen %d, a_d = %.3f');
titlename = sprintf(str,GEN,AD0);
%title(titlename)
xlim([0 2])
set(gca,'XTick',0:0.5:2)
set(gca,'XTickLabel',{'0.0','0.5','1.0','1.5','2.0'})
ylim([0 1]) 
set(gca,'YTick',0:0.2:1)
set(gca,'YTickLabel',{'0.0','0.2','0.4','0.6','0.8','1.0'})

savefig(['analysis/gen',num2str(GEN),'/fracmethvtime_v',num2str(HP1),'ad',num2str(AD0),'.fig'])

fprintf('figure 1 done \n')


figure()
plot([0,TI:DT:TF],yasmp,'Color','k','LineStyle','--','Linewidth',2)
hold on

for I = 3:-1:1
    plot([0,TI:DT:TF],gmetric_avg(I,:),'Color',color(I,:),'Linewidth',2)
    hold on 
end

xlabel('Time','Fontsize',18)
ylabel('g','Fontsize',18)
set(gca,'Fontsize',14)
str = char('Gen %d, a_d = %.3f');
titlename = sprintf(str,GEN,AD0);
%title(titlename)
xlim([0 2])
set(gca,'XTick',0:0.5:2)
set(gca,'XTickLabel',{'0.0','0.5','1.0','1.5','2.0'})
ylim([0 1]) 
set(gca,'YTick',0:0.2:1)
set(gca,'YTickLabel',{'0.0','0.2','0.4','0.6','0.8','1.0'})

savefig(['analysis/gen',num2str(GEN),'/gmetricvtime_v',num2str(HP1),'ad',num2str(AD0),'.fig'])

fprintf('all done \n')

end
